@@ -1,20 +1,20 @@
-/* internal.h	internal header file for libstringprep
- * Copyright (C) 2002  Simon Josefsson
+/* internal.h	Internal header file for libidn.
+ * Copyright (C) 2002, 2003  Simon Josefsson
  *
- * This file is part of Libstringprep.
+ * This file is part of GNU Libidn.
  *
- * Libstringprep is free software; you can redistribute it and/or
+ * GNU Libidn is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * Libstringprep is distributed in the hope that it will be useful,
+ * GNU Libidn is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with Libstringprep; if not, write to the Free Software
+ * License along with GNU Libidn; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  */
@@ -85,6 +85,7 @@
 #include "stringprep_generic.h"
 #include "stringprep_nameprep.h"
 #include "stringprep_kerberos5.h"
+#include "stringprep_xmpp.h"
 #include "punycode.h"
 #include "idna.h"
 
